package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````314``#0```!H@0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````B'H`
M`(AZ```%`````!````$```#(?0``R(T``,B-``!\`@``J`(```8`````$```
M`@```-!]``#0C0``T(T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,A]``#(C0``R(T``#@"```X`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`J_([;^@K&T/_HVA?
M8CY^`_UDUB41````30````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A-````3@```%(```!7````6````&````!A````8@``````
M``!D````90````````!F````9P```&H```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````>!``````
M```#``@```````"0`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```/T!`````````````!$```"&`0``
M```````````2````%P``````````````$@```-8!`````````````!(````?
M```````````````2````)@``````````````$@````H"`````````````!(`
M``#B`0`````````````2````+P``````````````(````!0#````````````
M`"$```!'```````````````2````30``````````````$@```%0`````````
M`````!(```#3`@`````````````2````Z0(`````````````$@```%L`````
M`````````!(````E`@`````````````2````8@``````````````$@```*L"
M`````````````!(```!I```````````````2````<0``````````````$@``
M`,P"`````````````!(```!Y```````````````2````E`(`````````````
M$@```($``````````````!(```"*```````````````@````X@(`````````
M````$@```*8``````````````!(```"K```````````````2````L@``````
M````````$@```*,!`````````````!8```"R`@`````````````2````4@(`
M````````````$@```+L``````````````!(```!$`@`````````````2````
M6`,`````````````$@```+T"`````````````!$````3`P`````````````1
M````=@(`````````````$@`````#`````````````!(````5`P``````````
M```1````P@``````````````$@```,L``````````````!$```"4`0``````
M```````2````W0``````````````(@```.P``````````````"`````"`0``
M```````````2````LP``````````````$@```&("`````````````!(````'
M`0`````````````@````GP(`````````````$@```"$!`````````````!(`
M``#'`0`````````````2````)@$`````````````$@```(0"````````````
M`!(````L`0`````````````2````M@$`````````````$@```#H!````````
M`````!(```!+`0`````````````2````(`(`````````````$@```#$"````
M`````````!(```!1`0`````````````2````:P(`````````````$@```-L"
M`````````````!(```#X`@`````````````2````8`$`````````````$@``
M`!L"`````````````!(```!G`0`````````````2````;@$`````````````
M$@```!(#`````````````"$```!_`0`````````````2````8`0``'"0````
M````$``3``T#``!Q$P``W`$``!(`"@#W`0``G3@```(````2``L`F@,``)$E
M``"H!```$@`*`'`$``!%+```S````!(`"@!W`P``Y1L```0````2``H`%`0`
M`'D0```"````$@`(`+T#```Y*@``#`(``!(`"@`:!```1)`````````0`!,`
M2`0``.D;``#(`0``$@`*`/4#``!$D````````!``$P"(`P``K20``.0````2
M``H`IP,``*T:``!(````$@`*`*\#``"5(@``;````!(`"@#3`P``T38``/X`
M```2``H`Z`,``+$=```D````$@`*``$$``!PD````````!``$P`)!````2,`
M`%`````2``H`:P0``'"0````````$``3`#T#``!I%0``1````!(`"@`H!```
MU1T``!@!```2``H`W@,``$"0```$````$0`2`$$$``!$D````````!``$@#Z
M`P``314````````2``H`$00``'4V``!<````$@`*`$8#``"1)```'````!(`
M"@!A`P``]1H``/`````2``H`500``-$W``#,````$@`*`%\$``!PD```````
M`!``$P`T!```[1X``*@#```2``H``&]P96YD:7(`;65M8VUP`'-T9&5R<@!R
M96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF
M;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S
M=')N8VUP`'-T<G)C:'(`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`&]P96X`<W1R<W1R`'9F<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?
M7W-T86-K7V-H:U]G=6%R9`!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R
M86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`
M<FUD:7(`7U]S=&%T7W1I;64V-`!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`%]?
M;'-T871?=&EM938T`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G
M971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT
M7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!03%]M96UO<GE?=W)A<`!S=')C<'D`<F5A9&1I<@!S=')T;VL`<W1R9'5P
M`'!T:')E861?871F;W)K`'-P<FEN=&8`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UA<FUV-RYS;RXQ`%]S=&%R
M=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A
M<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?
M7V)S<U]S=&%R=`!?7V5N9%]?`'!A<E]D:64`<VAA7VEN:70`7U]B<W-?<W1A
M<G1?7P!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD
M<')O9P!S:&%?9FEN86P`7U]B<W-?96YD7U\`7V5N9`!P87)?8VQE86YU<``O
M=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210```,B-```7````S(T``!<`
M``"\CP``%P```,B/```7````U(\``!<`````D```%P```!"0```7````%)``
M`!<````<D```%P```""0```7````))```!<````HD```%P```"R0```7````
M-)```!<````XD```%P```$"0```7````P(\``!4%``#$CP``%08``,R/```5
M#@``T(\``!4?``#8CP``$R0``-R/```5*@``X(\``!4N``#DCP``%3```.B/
M```5,@``[(\``!4S``#PCP``%3<``/2/```5/```^(\``!4^``#\CP``%4(`
M`,R.```6`P``T(X``!8$``#4C@``%@<``-B.```6"```W(X``!8)``#@C@``
M%@H``.2.```6"P``Z(X``!8,``#LC@``%@T``/".```6#@``](X``!80``#X
MC@``%A$``/R.```6$@```(\``!83```$CP``%A0```B/```6%0``#(\``!86
M```0CP``%A<``!2/```6&```&(\``!89```<CP``%AH``""/```6&P``)(\`
M`!8<```HCP``%AT``"R/```6'@``,(\``!8@```TCP``%B$``#B/```6(@``
M/(\``!8C``!`CP``%B4``$2/```6)@``2(\``!8G``!,CP``%B@``%"/```6
M*0``5(\``!8L``!8CP``%BT``%R/```6+P``8(\``!8Q``!DCP``%C(``&B/
M```6,P``;(\``!8T``!PCP``%C4``'2/```6-@``>(\``!8X``!\CP``%CD`
M`("/```6.@``A(\``!8[``"(CP``%CT``(R/```6/P``D(\``!9```"4CP``
M%D$``)B/```60P``G(\``!9$``"@CP``%D4``*2/```61@``J(\``!9'``"L
MCP``%D@``+"/```620``M(\``!9*``"XCP``%DP```&UO>@!0'!'!.`MY03@
MG^4.X(_@"/"^Y3!^````QH_B!\J,XC#^O.4`QH_B!\J,XBC^O.4`QH_B!\J,
MXB#^O.4`QH_B!\J,XAC^O.4`QH_B!\J,XA#^O.4`QH_B!\J,X@C^O.4`QH_B
M!\J,X@#^O.4`QH_B!\J,XOC]O.4`QH_B!\J,XO#]O.4`QH_B!\J,XNC]O.4`
MQH_B!\J,XN#]O.4`QH_B!\J,XMC]O.4`QH_B!\J,XM#]O.4`QH_B!\J,XLC]
MO.4`QH_B!\J,XL#]O.4`QH_B!\J,XKC]O.4`QH_B!\J,XK#]O.4`QH_B!\J,
MXJC]O.4`QH_B!\J,XJ#]O.4`QH_B!\J,XIC]O.4`QH_B!\J,XI#]O.4`QH_B
M!\J,XHC]O.4`QH_B!\J,XH#]O.4`QH_B!\J,XGC]O.4`QH_B!\J,XG#]O.5X
M1_WG`,:/X@?*C.)D_;SE`,:/X@?*C.)<_;SE`,:/X@?*C.)4_;SE`,:/X@?*
MC.),_;SE`,:/X@?*C.)$_;SE`,:/X@?*C.(\_;SE`,:/X@?*C.(T_;SE`,:/
MX@?*C.(L_;SE`,:/X@?*C.(D_;SE`,:/X@?*C.(<_;SE`,:/X@?*C.(4_;SE
M`,:/X@?*C.(,_;SE`,:/X@?*C.($_;SE`,:/X@?*C.+\_+SE`,:/X@?*C.+T
M_+SE`,:/X@?*C.+L_+SE`,:/X@?*C.+D_+SE`,:/X@?*C.+<_+SE`,:/X@?*
MC.+4_+SE`,:/X@?*C.+,_+SE`,:/X@?*C.+$_+SE`,:/X@?*C.*\_+SE`,:/
MX@?*C.*T_+SE`,:/X@?*C.*L_+SE`,:/X@?*C.*D_+SE>$?]YP#&C^('RHSB
MF/R\Y0#&C^('RHSBD/R\Y7A'_><`QH_B!\J,XH3\O.4`QH_B!\J,XGS\O.4`
MQH_B!\J,XG3\O.4`QH_B!\J,XFS\O.4`QH_B!\J,XF3\O.4`QH_B!\J,XES\
MO.4`QH_B!\J,XE3\O.4`QH_B!\J,XDS\O.5/](!<\+6MZPP,S/C`#XNPS>D&
M$%U-7DL%DGU$ZU@&J06J!ZA;3!MH"9-/\``#__=:[UE*?$2B6%A+`Y+C6!%&
M&$8$D__WPNY52^-8'7@`+6;0'>YP+TM+!YA[1!MHTEC%')+XUC,$,$/P`P.P
M\8!/@OC6,W?2@`#_]UCO`T9)2DE,>D3?^"3AW_@DP19HW>D&$@AH?$3^1/Q$
M`2K#Z0`.GF##^`S`8V!EW0@?`_$,#`#K@@!1^`1/B$),^`1/^='4'``F.T\\
M27]$^&@J1@"6>41#^"1@__>P[@`H,=`W30BN?43H:/_W[.X$1C1(,49X1`#P
M(_E`LS)+>T38:/_W:.__]QSN,$HA2WI$TU@::`F;6D!/\``#,M$@1@NP\+W_
M][#N*4IZ1-!@,+/_]PKO%4L=[G`O>T0;:--8@_BN5HGG^&C_]^SNR>>H:!"Q
M`?#!^]'G'D@Q1GA$`/#O^*A@`"C)T//G&TL;2.-8>$091@.3__<([@0DH^<!
M(/_WQ.[_]S+O"GP``"Y[```R>P``)`$``!A[```\`0``.`$```0!``!*?```
M6'P``#8H```X*```)'P``.T%```*?```A"4``/)[``!">@``QGL``+@D```<
M`0``H"8``$_P``M/\``.`TEY1&A&(/`/#.5&`/`"^'9X```0M0`D`D8+20M(
M>40(6(2P"DL"D,M8W_@HP`.3`911^`P0`T8`D0.84O@$&__W4NX$L!"]2GD`
M`!0!``#\````"`$```9(!TL'2GA$>T2#0GI$`]`%2]-8`[$81W!'`+^.>@``
MC'H```1Y```0`0``"$@)2WA$>T0;&MD/!TH!ZZ,!21!Z1`/0!4O36`.Q&$=P
M1P"_9'H``&)Z``#0>```,`$``$_T@%P0M:WK#`S,^/@/#DL.3'M$&WA\1*.Y
M#4OC6".Q#$M[1!AH__<6[O_WN?\*2^-8&[$)2'A$__=<[0$B"$M[1!IP$+T`
MOR)Z``":>```*`$``,YY```,`0``/F0``/1Y``!/](!<"+6MZPP,S/CX#P=+
M!TI[1)M8*[$&20=(>41X1/_W[.V]Z`A`GN<`OSIX```L`0``N'D``/)C``!/
M](!<+>GX0ZWK#`S,^.`/'TN`1GM$`"@VT!Y*FUC3^`"0N?$`#S'0!7@/1@`M
M&+\]+12_`24`)1/1V?@`0&RQ3D8J1D%&($;_]T;M$+EC73TK$-!6^`1/`"SR
MT2!&O>CX@P5&%?@!/P`K&+\]*_G1I>L(!>'GINL)!@$UMA`L1#Y@($:]Z/B#
M!$;GYTQ&Y>?\=P``(`$``$_T@%P0M:WK#`S,^%@/%TH72WI$J+#36&E&&V@G
MDT_P``,$1O_WRNV@N02;`_1P0[/U($\8O[/U@$\-T`U*#$MZ1--8&F@GFUI`
M3_```PO1*+`0O0`@\><"(2!&__>6[+#Z@/!`">GG__?4[69W```D`0``.'<`
M`$_T@%SPM:WK#`S,^$@/-$HT2WI$TUBIL!MH)Y-/\``#$+$#>`1&6[DO2BY+
M>D336!IH)YM:0$_P``-/T2FP\+W_]TKL!48`*.[0*$;_]Y+LF+/#?`#Q$P8N
M*P+1<W@`*_/0PWPN*R_0($;_]Y+M!T8P1O_WCNTX1`(P__>:[#-&!D8:22)&
M>43_]W#M,$9I1O_W/NT!,#!&!=`$FP/T<$.S]8!/%]#_]W[L,$;_]T3M*$;_
M]V#L`"C+T2A&__><["!&__<@[:_G<W@N*\S1LW@`*[K0R.?_]Y/_YN?_]U[M
M[G8``"0!``#4=@``[B```$_T@%PMZ?!'K>L,#,SXV`\,1E9*5DMZ1--8@K`;
M:`&33_```PMX!48]*PB_`30@1O_W-NUI1@9&*$;_]^'^34^!1G]$`"A4T/_W
M*NV&0D?9`)M/ZH,(2$O_6"MX`"L8OSTK%+\!(P`C!]`K1A/X`2\`*AB_/2KY
MT5L;L!P81#YH__<>[$;X"`#HL2A&.VA3^`@0$/@!.STK&+\`*PMP"=!*'!#X
M`3L11CTK&+\`*P+X`3OVT3TC"D8+<!3X`3L"^`$_`"OYT2U**4MZ1--8&F@!
MFUI`3_```T71`K"]Z/"'"?'_.13X`3L)^`$_`"OYT>GG(4O_6-?X`(#8^``P
M>[-#1E/X!"])1@GQ`0D`*OC1`S&)`!I*>D03:+NY`2,(1A-@__?.ZX)&`"C,
MT$%&3^J)"$)&__?*Z\?X`*``(\WX`)`)\0$)2O@I,(;G0$;_]U[K@D8X8``H
MM=!/ZHD([>>91@@AUN?_]Z+L`+_Z=0``)`$``,YU```@`0``1G4``)IV``!/
M](!<,+6MZPP,S/C@#Q)('>YP3WA$`&@12A))>D116(6P"D8#D1!+$$D@6'M$
M>43_]U;L"4@`)7A$`&@,2PU*#4E[1"!8>D3-Z0`U>43_]S3K!;`PO0"_D'4`
M`&QU``!P=```-`$``(!?``#:'@``QB$``+\/``#8'@``$+0,20Q*W_@TP'E$
M"6AZ1!WN<`]2^`Q`0%@B1@A+"4F#L'M$>40!E`.P7?@$2__W%[P`OQYU```"
M=```-`$```Y?``!H'@``3_2`7'"UK>L,#,SX``"L]8!<S/@``$SX*`PP2C!+
MK?4`78:P>D336`WU`%$4,1MH"V!/\``#__?VZBI,*DI\1`.N`T9Z1$'R`0$P
M1@"4__?,ZD'R`0-"')I".=@!,#C0#?6`51`U3_2`4BE&,$;_]W+K!!XMVV`<
M__?^Z@-&0+.H0@+2`AF50B+3JT(=V$'R`0*40AS8(D881BE&__?0ZP`B`T8"
M51%)#4IY1`WU`%"*6!0P$6@":%%`3_```@K1&$8-]0!=!K!PO2H9DT+>TO_>
M`"/GY__WQNL`OZ1S```D`0``1AX``#0>```><P``__>&OT_T@%PMZ?!/K>L,
M#,SX``!,^-`,8$RM]85=8$J#L'Q$!49?2*)8#?6%4P*O#D9X1#E&!#,2:!I@
M3_```O_W0OTO(01&*$;_]^[JP+%52"E&>$3_]S?^*$932E!+>D0-]851TU@$
M,1IH"VA:0$_P``-`\(^`#?6%70.PO>CPCS!&__>LZDE)>43_]U3K@D8`*-S0
MW_@<@9KX`#`-\:@)^$2I\00&`"M1T"RQ448@1O_W1NH`*#[04$;_]U3K`D9#
M'E-$FD6#1CZ_`"%21`KQ`0,#TPO@DT(1<`30$O@!S;SQ+P_WT%!&__<^ZX-&
M*$;_]SKK6$0!,+#U@%^GTM_XM,!31OQ$0D9/](!1,$;-Z0#%__?PZ0$PL/6`
M7SS8.48P1O_WX.HPN5GXD#P#]'!#L_4`3QG0($D`('E$__?\ZH)&`"B#T)KX
M`#``*ZW1W+$C>"XK!=#?^&2@3_`!"_I$Q>=C>``KYM#UYP$A,$;_][SI`"C?
MT1)(,49X1/_WH_TP1O_W+.IHY]_X/*!/\`$+^D2LY__W[NK_WK9R```D`0``
M:AT``%0=``!X<@``+AT``!H=``"^'```?!P``#@<```L'```!AP``$_T@%P0
MM:WK#`S,^/@/+R$$1O_W[.D`L40<($:]Z!!`__?VN4_T@%PPM:WK#`S,^```
M3/@8##I*.DNM]8!=>D2#L`WU@%'36`0Q&V@+8$_P``,`*#K0`W@%1KNS__>>
MZ@$PL/6`7T?8`:PI1B!&__>XZ2!&__>2Z@$X($2@0@C9`"("X*!"0G`#T!#X
M`3DO*_C0+R$@1O_WJNEXLZ!"A+\`(P-P($;_][;I'TH=2WI$#?6`4=-8!#$:
M:`MH6D!/\``#*]$-]8!=`[`PO1=*%4MZ1`WU@%'36`0Q&F@+:%I`3_```QK1
M$DAX1`WU@%T#L+WH,$#_]XRY`"#6YPU*"4MZ1`WU@%'36`0Q&F@+:%I`3_``
M`P+1"$AX1.;G__=$ZLYP```D`0``7G```#QP``#D&@``#'```+0:``!/](!<
M<+6MZPP,S/CH#\Q*S$MZ1,Q-TUC,3H*P?40;:`&33_```WY$;$8A1C!&__?'
M^["QQDL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]['[
M`"CHT;Q.?D0A1C!&__>I^["QMTL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#
M^`0K`"KZT2%&,$;_]Y/[`"CHT:Y.?D0A1C!&__>+^["QJ$L`F.M8&6@!ZX`#
M6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]W7[`"CHT:!.?D0A1C!&__=M
M^["QF4L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]U?[
M`"CHT9).?D0A1C!&__=/^["QBDL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#
M^`0K`"KZT2%&,$;_]SG[`"CHT81.?D0A1C!&__<Q^["Q>TL`F.M8&6@!ZX`#
M6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]QO[`"CHT79.?D0A1C!&__<3
M^["Q;$L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]_WZ
M`"CHT6A.?D0A1C!&__?U^K"Q74L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#
M^`0K`"KZT2%&,$;_]]_Z`"CHT5I.?D0A1C!&__?7^K"Q3DL`F.M8&6@!ZX`#
M6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]\'Z`"CHT4Q.?D0A1C!&__>Y
M^K"Q/TL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]Z/Z
M`"CHT3Y.?D0A1C!&__>;^K"Q,$L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#
M^`0K`"KZT2%&,$;_]X7Z`"CHT3!((49X1/_W?OH!1ABQ+4AX1/_W>/LL2"%&
M>$3_]W/Z`488L2I(>$3_]VW[*4@A1GA$__=H^@%&L+$F2'A$__=B^R5*$4MZ
M1--8&F@!FUI`3_```Q71(4DB2'E$>$0"L+WH<$#_]T^['T@A1GA$__=*^@%&
M`"CDT!Q(>$3_]T/[W^?_]Y;HOF\``"0!``"T;P``FAH``"`!``!H&@``-!H`
M``0:``#0&0``I!D```09```X&0``"!D``-@8```@&```:A@``$88``!H&```
M<!@``'(8``">%P``T&P``-`9``#2%P``1A@``-`7``!/](!<`+6MZPP,S/CP
M#Q-*$TMZ1!-(@[#36&E&>$0;:`&33_```__W]_E`L0!X`"@8OS`H#+\!(``@
M@/`!``I*!TMZ1--8&F@!FUI`3_```P+1`[!=^`3[__<TZ!9L```D`0``0!<`
M`.9K``!/](!<#[0`M:WK#`S,^/`/"TD,2WE$RUB#L!MH`9-/\``#!*I2^`0;
M!TL(2'M$`)(;6!AH_O=8[_\@_O>>[P"_J&L``"0!``"0:P````$``$_P``PM
MZ?!'3_2`/JWK#`RLZPX.K/6`7,SX``#T1?G13O@X#`(A0$U`3*WU@#V&L'U$
M+%D-]8`V)&AT84_P``0`(@`C`)&`1O[WN.X!.&'Q``?Z%X#JYW.;&INR4T";
M&@;Q%`9BZP("QAIGZP('`"]+VT_P"`D#K<#R`0D`(3)&.T9`1@"1_O>:[K'Q
M_S\(O[#Q_S]!T$I&*49`1O[W7.]#'#;0!R@FV0@X+!@CTM_X@*#Z1`+@`3RL
M0AS3"")11B!&_O=&[@`H]=%D&Z`91^OD<1A*%4MZ1`WU@#336!0T&F@C:%I`
M3_```QK1#?6`/0:PO>CPA[;U@#9G\0`'M_'_/PB_%O6`/[C13_#_,`%&W^<)
M2'A$__=+_PA(>$3_]T?__O=R[P"_/&L``"0!``#^:P``EFH``!@6````%@``
M3_2`7`BUK>L,#,SX^`_^]V+O_O?`[@"Q`&@(O4_T@%SPM:WK#`S,^-@/+$HL
M3BU+>D2%L--8?D0%1@*I,$8;:`.33_```__WZ?@0L0-X!$:+N25*(TMZ1--8
M&F@#FUI`3_```SC1*48@2'A$!;"]Z/!`__?3N2E&_O=H[EBQ'$H82WI$TU@:
M:`.;6D!/\``#(M$%L/"]*$;^]Q#O!T8@1O[W#.\X1`(P_O<8[A%+$DDJ1GM$
M>40`E`1&_O?N[@]*"$MZ1--8&F@#FUI`3_```P2_(48P1LG0_O?V[OQI``#"
M%0``)`$``-9I``".%0``JFD``%H4``!<%```:FD``$_T@%PMZ?!/K>L,#,SX
MP`['L`WQR`K41M_X"!3?^`A$W_@()'E$BEA\1`3Q#`,$\1@.+*T2:$623_``
M`@60D^@'`(7H!P"^Z`\`K.@/`)[H`P`P-`WQO`F,Z`,`E.@'`(GH!P#R2-_X
MS(,&KC%&>$3X1/_W4_@@L0-X!$8`*T#P5H'^]ZCN_O<&[@`H`/"2@`=H`"\`
M\(Z`.$;^]Y#N0``!,/[WG.TZ>`1&@49:L=_XB+/[1"!&64;^]V[N%_@!+P(T
M`"KVT=U(>$0"X%KX!`^(L3%&__<B^`1&`"CVT`-X`"OST/_W9O@`*._0($;^
M]Z+M!$9XN57X!$MDL2-X`"L`\`&!($;_]U7X`"CNT57X!$L`+/+1($;^]U#N
M!49(1O[W3.X%1`7R!$4H1O[W5NW-^`20@4;"2\))>T0`D\)+(D9[1'E$_O<H
M[D_TX'%(1O[W`.X!,`71_O?V[0!H$2A`\-B`,49(1O[W`NX$1@`H.-"V2`6:
MMDE8^```2T82:`!H>43^][;M`"6R2J=+>D336!IH19M:0$_P``-`\#N!*$9'
ML+WH\(_^]T3M!T8`*$#PJX!9^`0+6+$Q1O[WKO\`*/?0`W@`*^[16?@$"P`H
M\]$-(/[W`NV?3U,B!$:!1G]$9.<S:0/T<$.S]8!/P-&W:?[W\.V'0KO1,VG#
M\P@#L_7@?[71*$;^]^CL!4:32#%&>$3^]X+_`48`*`#PF8`%FQAH__<8^H)&
M`"@`\)&`4$;^]\3M`RB`1A#9B$D$.%!$>43^]Z;L2+FX\00/`/#-@-!$&/@%
M/"\K`/#'@(%(,49X1/[W6O\@L0-X,"L8OP`K!M$`(5!&_O?B[`9&`"AKT7E)
M>4AY1'A$__='^/[W?.QW2G=+>$EZ1-_XX(%X3WA.S>D``GM$2D8H1GE$_O=T
M[?A$?T1^1!+@_O=&[0-H$2L4T?[W8.R$1@$T0T9*1CE&*$;-Z0%&S?@`P/[W
M7.U/].!Q*$;^]S;M`3#ET$A&_O<X[61(*49X1/_W#_@H1O_W#/Y!YQQ&!>?^
M]UCM0``!,,;F34D%FECX`4!;21)H2T8`D'E$(&C^]^3L+.?_]_7]5TH]2WI$
MTU@::$6;6D!/\``#9]$@1D>PO>CP3_[W;[P%F]/X`*!JY__W,?VQ\0`(!T:-
MVT_P``JP\0H":/$``S!&S?@`H`WQX`O^]_[K!B(P1EE&_O?([`8H1=%/](9#
M.)K$\D$SFD)_]'*O1/)(4[OX!"":0G_T:Z^W\3(":/$``S!&S?@`H#JL_O?>
MZR@B,$8A1O[WJ.PH*"71,4HQ2S))>D0!DBA&2D8`E'M$>42-^!"A_O?8[(#G
M!9M?:``O/_0TKSA&_O?@[`,H?_8NKR=)!#@X1'E$_O?$ZP`H"+^Z1B/G_O?8
M[")(>$3_]Z?\`+\(:0``2&H``"0!``""$P``O&@``%X4``#D$P``ZA,``-03
M``#6$@````$``.83``">9P``*!,``*H3``""$P``_A$``+H3``#8$0``$!0`
M`'(1``!$$P``9A$``$P3``#R$P``^!````@2``#V90``U!(``#H0````$@``
MQ!$``+@1``!/](!<\+6MZPP,S/C@#V]*;TMZ1--8@[`;:`&33_```V!+'>YP
M3WM$&VAN1N58:4B5^&0P,49X1(7X93#^]QK^$+$#>#$K>-#_]S3Z5DM[1!MH
MY5A@22A&`R,!(GE$_O>TZP5&<+%12\)H>T0;:!%H6DK@6'I$_O>TZ^MH&6B+
M:%L";]1*2%9)>$0`:`,C`2(@6'E$_O>8ZP5&>+%12#%&>$3^]^?]`D8`*$K0
M04OI:'M$&V@):.!8_O>2ZSY+2DE[1!MHY5@!(GE$*$;^]][J1DH!1GI$*$;^
M]X+K-TL`(GM$&VA"2.-8,49X1(/X92#^]\#]/TQ\1*!@H+%/].!Q_O?4ZT,<
M$2@8OP$K0-@Z2B]+>D336!IH`9M:0$_P``,TT0.P\+U@:/_W%OV@8``HY-$R
M2'A$_O?"ZD-X`"N)T(+G_O>[_P=&F+$=2^IH>T0;:!%H`D;@6/[W0NLX1O[W
MKNNKYQ=+>T0;:.!8_O?6ZHCG%4LB2GM$&VAZ1.EH4F@):!)HX%C^]RSKE^?^
M]\CK'$H#1AQ(>D32Z0$2>$0):/[WC.IV90``3F4``#)E```490``[&0``-QD
M``"\9```3F0``#9D```F9```<F0``"0!``!F#P``$!$``/P0``#F$```M`X`
M`+00``#`$```7@X``"YE``!R8P``:!```*ID``".9```)!```$_T@%PPM:WK
M#`S,^.@/*4HI2WI$!$8I2(.PTUAI1GA$&V@!DT_P``/^]Q[]<+$#>``K&+\P
M*PR_`2,`(X/P`0,`+`R_`",#\`$#6[D<2AI+>D336!IH`9M:0$_P``,GT0.P
M,+TC>``K\-`@1O_WD/@O(05&_O=PZ@"Q11PH1O[W@.H0200B>43^]UKJ`"C=
MT0U*"4MZ1--8&F@!FUI`3_```P71($8#L+WH,$#^]V2]_O<PZV9B```D`0``
MC@T``"AB``#J#0``Y&$``$_T@%PMZ?!/K>L,#,SX>`[?^$0IW_A$.7I$TUC9
ML!MH5Y-/\``#@T8`\1P"!JE<,%+X!#L;NH)"0?@$/_C1#?$<#`BJW.D-3DBO
MW.D`!MSX/#``X`Y&'4;3:5+X!!]+0&-`0T!/ZO-SET)T1C!&KD:38^_11_:9
M'MOI`C+<Z0!%V_@$H%-``^H*`X/J`@C;^`@PQ?:"+H/JN@;;^``P=$0>0-OX
M"#!U1%Y`V_@`,-SX&`!/ZK,)W/@(,(GJN@(!D]OX$#!P1!Q$V_@,,-SX(!`=
M1-OX`#`N1`3K\V1$1`&=!NOT8P+J!`;;^`@@=4051-SX#""&ZKH&-40"ZPX&
M!NNZ`@&2W/@0(`7K\V4"ZPX&W/@4('%$`NL."`;K"0+<^!Q@`I)V1`;KM08#
MEMSX*&`(Z[0(=D0$EMSX+&#<^"0@=D0%EHGJM`8>0(;J"0D!GD_JLP.Q1(/J
MM`8N0(;JM`8"G`GK]6DF1(/JM00&Z_EF!.H)!$_JN0D81%Q`B>JU`S-`1$2#
MZK4#!.OV9`-$`^OT8(GJM@,C0`6=@^H)"`.;3^JT!)A$!)M)1`/K!`F$ZK8#
M`T"#ZK8#".OP:`M$`^OX883JL`,#Z@@#3^JX"')$7$"(ZK`#`NNV`@M`%$2#
MZK`#!.OQ9$M$!>NP!0/K]&"(ZK$#W/@P("-`3^JT!(3JL09.]J$W<D2#Z@@#
M!D`K1(;JL08"ZP@%W/@T(`/K\&,N1(3JL`5R1!U``NNQ`F5`%43<^#@@!NOS
M87)$3^JS`Q1$W/@\((/JL`9R1`Y`!>OQ90+KL`*&ZK`&@^JQ`"A`)D180`;K
M]6001$_JM07<^$`@`.OT9H7JL0!R1"!`&D2`ZK$`W/A$,!!$A>JT`G-$,D!J
M0`/KL0,31-SX2"!/ZK8!<D051-SX3"``Z_9@@>JT!G)$!D`#Z_!C`NNT`H;J
MM`:!ZK`$'$!,0!1$W/A0(,;VV6<Z1#5$5AC<^%00!>OS93E$3^JS`P'KL`Z#
MZK`!:4!P&-SX6!`$Z_5D.43.&(/JM0'<^%PP`.OT8#M$84!/ZK0$<40#Z[4.
MA.JU`T-`]1C<^&`P`>OP83M$'AG<^&0PA.JP!`7K\64[1$Q`3^JQ`71$`^NP
M#H'JL`-K0/`8W/AH,`3K]60[1%X8W/AL,('JM0%A0#M$<41/ZK0.`.OT8`/K
MM0B.ZK4#0T#T&-SX<#`!Z_!A.T0#ZPX%W/AT,([JL`8$Z_%D.T1.0$_JL0$#
MZ[`.@>JP`V-`Z!C<^'@P1D0[1%T8@>JT`]SX?!`&Z_1F`.OV8#E$<T!/ZK8&
M<T0!Z[0.ANJT`4%`;!C<^(`02_;<0CE$C1G<^(00`^OP8X;JL`8$Z_-D.41>
M0$_JLP-V1`'KL`Z#ZK`!84!H&-SXB!`&Z_1F.43-&-SXC!"#ZK0#`.OV8#E$
M<T!/ZK8&<T0!Z[0.ANJT`4%`;!C<^)`0`^OP8SE$`>L&"-SXE!"&ZK`%!.OS
M9#E$74!/ZK,#`>NP!H/JL`%A0`CK`0#<^)@0=40Y1`7K]&4!ZP,.@^JT`]SX
MG!!K0`#K]6`S1$_JM04#Z_!CA>JP!CE$`>NT`5Y`#D3<^*`0R/8;<H7JM`01
M1$1`#41T1-SXI!`$Z_-D3^JS`T/JL`<11`'KL`$G0`/JL``X0P;K]&8H1$/J
MM`4#ZK0'-4`]0PU$W/BH$`#K]F`11!E$W/BL,$_JM@9&ZK0'$T0#Z[0#!T`&
MZK0$/$,%Z_!E#$1&ZK`!*4`&ZK`'#T/<^+00!.OU9!]$3^JU!=SXL#!%ZK`.
M$4031`'KL`$.Z@0.!>JP`!Y$3NH`#@?K]&>V1$7JM`8.Z_=@/D`%ZK0.1NH.
M!@Y$W/BX$$_JMP<11`U$W/B\$$?JM`X11`'KM`$.Z@`.!^JT!$[J!`X&Z_!F
MKD1'ZK`%#NOV9#5`!^JP#D7J#@4-1-SXP!!/ZK8&$40/1-SXQ!!&ZK`.$40!
MZ[`!#NH$#@;JL`!.Z@`.!>OT9;Y$1NJT!P[K]6`O0`;JM`Y'Z@X'#T3<^,@0
M3^JU!1%$#D3<^,P01>JT#A%$`>NT`0[J``X%ZK0$3NH$#@?K\&>V1$7JL`8.
MZ_=D/D`%ZK`.1NH.!@Y$W/C0$$_JMP<11`U$W/C4$$?JL`X11`'KL`$.Z@0.
M!^JP`$[J``X&Z_1F1^JT`*Y$#NOV93!`!^JT#D#J#@!,\M83"$3<^-@03^JV
M!A%$`>L'#MSXW!``Z_5@$40!Z[0'1NJT`2E`!NJT!"%#1NJU!'%$!$`&ZK4.
M1.H.!`'K\&$\1`3K\6?<^.!`3^JP`!1$)D3<^.1`0.JU#A1$!.NU!`[J`0X`
MZK4%3NH%#K9$0.JQ!@[K]V4^0`#JL0Y&Z@X&)D3<^.A`3^JW!Q1$!$3<^.P`
MS/9B(Q!$1^JQ`BI``.NQ``?JL0$10]SX\"`&Z_5F&D0"ZP<.W/CT("%$1^JU
M!`'K]F$'ZK4'&D0T0$_JM@8\0P+KM0>&ZK4"2D`@1`[K`@3<^/@@`.OQ8!I$
ME1F&ZK$&ANH``KX8W/C\(`3K\&0:1$_JL``"Z[$'@.JQ`F)`%43<^``A!NOT
M9AI$$1B`ZK0`@.H&`K@8W/@$(07K]F4:1$_JM@8"Z[0'ANJT`FI`$43<^`@A
M`.OU8!I$`NL&#H;JM0:&Z@`"`>OP9+D8W/@,(4_JL``:1`+KM0:`ZK4"8D`.
MZP(%W/@0(0'K]&$:1!<8@.JT`(#J`0*P&-SX%"$%Z_%E&D1/ZK$!`NNT!H'J
MM`)J0+P8W/@8(0#K]6`:1%<8@>JU`8'J``*Q&-SX'"$$Z_!D&D1/ZK```NNU
M!H#JM0)B0+T8W/@@(0'K]&$:1!<8@.JT`(#J`0(%Z_%E%D1/ZK$!W/@D(8'J
MM`!H0!I$`NNT`CP8W/@H`0;K]6881`A$@>JU`7%`!.OV9`I$`NOT8=SX+"%/
MZK8&&D0"Z[4'ANJU`F)`$$3<^#`A`.OQ8!I$E1F&ZK0&ANH!`KX8W/@T(4_J
ML0$:1`+KM`*!ZK0$1$`&Z_!F+$3;^`Q0!.OV9`7KM`7+^`Q0W.E.5QU$.T3;
M^`!P#42!ZK`!<4`[1$_JM@8#Z[`#"D2&ZK```NOT88#J!`*H&(;JM`)*0!-$
MV_@((`#K\6`#Z_!CV_@00`+KL0)01,OI`##+^`@@"TH)2R9$>D3+^!!@TU@:
M:%>;6D!/\``#`M%9L+WH\(_]]WKN`+^480``)`$``'18``!/](!<<+6MZPP,
MS/CP#V`@0O(!-4KVB33]]V[M1?)V1DWV_D$`(L;R177.]LUTP.D`5`BEU>D`
M1<#I!$7)]KH!P?(R!L9@@6""8<)E<+T`OZ_S`(#PX=+#`````$_T@%PMZ?!'
MK>L,#,SXX`\51H!&0VF*1M$`@FE;&$-A*+\!,L!M`NM5<LCX&"`(\1P'^+'`
M\4`$"/$<!ZQ".$2HORQ&4$54T@,9FD4HOPKK!`9)TU%&(D;]]P3NV/A<,"-$
M0"O(^%PP.-%`1O_WZ/JR1BT;/RTCW51&"/%<"0KQ0`:G0BS23$4NT[)&.T8$
M\4`.U/@`P&!HH6CB:!`T=$7#^`#`6&"98-I@`_$0`_#10$9`/?_WQ/H_+0;Q
M0`;@W%=%$M,#V0KK!0.?0@S3*D911CA&_??&[<CX7%"]Z/"'LD;3V;="T=+_
MWGL9FD7NTO_>"NL$!JW9L$*KTO_>`+]/](!<+>GP0:WK#`S,^.@/3_"`#$MI
M`?$<!Y/Z@_C#\\4#BFD'^`/``3,X*PQ&!486ND3=`"'#\4`"^!C]]YSL($;_
M]WWZ."(`(3A&_?>4["!&Q.D5:/_W<_KC>"!&*W!CB&MP(V@;"JMP(VCK<.-Y
M*W'CB&MQ8V@;"JMQ8VCK<>-Z*W)CB6MRHV@;"JMRHVCK<N-[*W/CB6MSXV@;
M"JMSXVCK<^-\*W1CBFMT(VD;"JMT(VGK=+WH\$']]S&]`"'X&,/Q.`+]]UCL
MP><!M;WH`4!P1SX```!!````#````$$````1````00```"<```!!````-@``
M`$$````#````00````8```!!````%0```$$````/````00````X```!!````
M)@```$$````3````00```"D```!!`````@```$$````9````00````H```!!
M````"P```$$``````````````"5S+R5S````1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S
M`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S
M)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!
M4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%2
M7T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@````!L<V5E:R!F86EL960`````<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P``
M``!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````'-H
M;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E
M<W1E;7`M)74M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z
M.E9%4E-)3TX`````,2XP-C$```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%
M4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*
M;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M
M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD
M1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA
M;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*
M<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK
M7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H
M.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I
M>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK
M7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*
M<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'
M24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^
M/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ
M93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@
M,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T
M;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@
M+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N
M86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B([
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"
M14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H
M<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H
M*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*
M34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S
M<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A
M;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S
M92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,[
M"GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H
M)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T
M<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D
M;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B
M=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@
M)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R
M(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@
M(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?
M<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/
M9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T
M+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R
M97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S
M("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A
M=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT
M*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA
M;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D
M;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.
M;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T
M(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I
M('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G
M?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D
M7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I
M92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F
M.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P
M87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D
M<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]2
M1%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q
M<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E
M*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X
M="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I
M;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H
M+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*
M?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H
M;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%
M("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N
M(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB
M961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S
M("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T
M85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E
M('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL
M92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H
M)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&
M:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI
M=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z
M("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O
M9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T
M*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S
M*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P
M871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS
M92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?
M<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@
M)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP
M0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D
M;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#
M2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D
M8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@
M/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?
M9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.
M?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A
M<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@[
M"BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H
M("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M
M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA
M;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64[
M"GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@
M>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y
M<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E
M;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*
M9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?
M1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*
M?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````$-!0TA%```^````00````P`
M``!!````$0```$$````G````00```#8```!!`````P```$$````&````00``
M`!4```!!````#P```$$````.````00```"8```!!````$P```$$````I````
M00````(```!!````&0```$$````*````00````L```!!````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'$6```-%@```0```!T#```!````
M*`,``!T```!\!```#````'D0```-````G3@``!D```#(C0``&P````0````:
M````S(T``!P````$````]?[_;W`!```%````#`D```8```!<`@``"@```)H$
M```+````$````!4``````````P```,".```"````X`$``!0````1````%P``
M`)@.```1````J`T``!(```#P````$P````@````>````"````/O__V\!```(
M^O__;Q``````````````````````````````````````````````````````
M````T(T`````````````@!```(`0``"`$```@!```(`0``"`$```@!```(`0
M``"`$```@!```(`0``"`$```@!```(`0``"`$```@!```(`0``"`$```@!``
M`(`0``"`$```@!```(`0``"`$```@!```(`0``"`$```@!```(`0``"`$```
M@!```(`0``"`$```@!```(`0``"`$```@!```(`0``"`$```@!```(`0``"`
M$```@!```(`0``"`$```@!```(`0``"`$```@!```(`0``"`$```@!```(`0
M``"`$```@!```(`0``"`$```@!```(`0``"`$```<1,`````````````G3@`
M````````````>1``````````````````````````````````````````````
M````````````D```"E!!4BYP;0H`````:#P``(`Y````````0#H``$0Z``!<
M/```B#D``&0\````````2#P``%`\````````<#P``$=#0SH@*$%L<&EN92`Q
M,RXR+C%?9VET,C`R,S$P,30I(#$S+C(N,2`R,#(S,3`Q-`!!,@```&%E86)I
M``$H````!3<M00`&"@=!"`$)`@H$$@03`10!%0$7`Q@!&@(<`1X"(@$`+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M````"P````$````"````-`$``#0!```8```````````````!`````````!,`
M```'`````@```$P!``!,`0``)```````````````!``````````F````]O__
M;P(```!P`0``<`$``.P````$``````````0````$````,`````L````"````
M7`(``%P"``"P!@``!0````,````$````$````#@````#`````@````P)```,
M"0``F@0``````````````0````````!`````"0````(```"H#0``J`T``/``
M```$``````````0````(````20````D```!"````F`X``)@.``#@`0``!```
M`!$````$````"````%(````!````!@```'@0``!X$```"```````````````
M`@````````!-`````0````8```"`$```@!```/`"``````````````0````$
M````6`````$````&````<!,``'`3```L)0`````````````(`````````%X`
M```!````!@```)PX``"<.```"````````````````@````````!D`````0``
M``(```"D.```I#@``.!!``````````````0`````````;`````$````"````
MA'H``(1Z```$```````````````$`````````'8````.`````P```,B-``#(
M?0``!```````````````!`````0```""````#P````,```#,C0``S'T```0`
M``````````````0````$````C@````8````#````T(T``-!]``#P````!0``
M```````$````"````)<````!`````P```,".``#`?@``0`$`````````````
M!`````0```"<`````0````,`````D````(```$0```````````````0`````
M````H@````@````#````1)```$2````L```````````````$`````````*<`
M```!````,`````````!$@```,0```````````````0````$```"P`````P``
M<```````````=8```#,```````````````$``````````0````,`````````
<`````*B```#````````````````!````````````
